==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation type="obsolete">Dodaj wtyczki</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="vanished">Szukaj:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation type="obsolete">Dodaj wtyczkę</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zamknij</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Wersja: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Zaawansowany, łatwy w obsłudze i szybki pulpit bazujący na Qt.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Prawa autorskie: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Strona: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Licencja: %1</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQt jest dostępny w wielu językach dzięki wspanialej pracy ekip tłumaczy z całego świata.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Nie</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Skrzynka narzędziowa pulpitu LXQt - Informacje techniczne&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">Wersja</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">Wersja debugowa</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">Konfiguracja systemu</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">Udostępniany katalog</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">Tłumaczenia</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Katalogi użytkownika&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Ścieżka dostępu plików Xdg</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Ścieżka dostępu konfiguracji Xdg</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Katalogi plików Xdg</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Ścieżka dostępu pamięci podręcznej Xdg</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Ścieżka dostępu środowiska uruchomieniowego Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Katalogi autostartu Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Ścieżka dostępu autostart Xdg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>Uśpij sesję</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz uśpić swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu nie jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernuj sesję</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz zahibernować swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz ponownie uruchomić swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz wyłączyć swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz się wylogować?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Uśpienie nie powiodło się.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation>Błąd wygaszacza ekranu</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Błąd podczas aktywacji wygaszacza ekranu</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie uruchamia się (crash).</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie jest poprawnie zainstalowany.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie może zostać uruchomiony.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Błąd składni argumentów xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Akcja &quot;aktywacja&quot; zawiodła. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Wystąpił błąd podczas wywołania wygaszacza ekranu. Nieznany błąd - nieudokumentowany zwrot wartości z xdg-screensaver=%1.</translation>
    </message>
</context>
<context>
    <name>LXQt::ShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Wyczyść</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Brak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Błąd menedżera zasilania</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface jest nieprawidłowy</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Błąd menedżera zasilania (D-BUS call)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">O LXQt</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">O</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Autorzy</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Podziękowania</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Tłumaczenia</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Informacje techniczne</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/liblxqt/liblxqt_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation type="obsolete">Dodaj wtyczki</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="vanished">Szukaj:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation type="obsolete">Dodaj wtyczkę</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zamknij</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Wersja: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Zaawansowany, łatwy w obsłudze i szybki pulpit bazujący na Qt.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Prawa autorskie: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Strona: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Licencja: %1</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">LXQt jest dostępny w wielu językach dzięki wspanialej pracy ekip tłumaczy z całego świata.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Nie</translation>
    </message>
    <message>
        <source>&lt;b&gt;LXQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Skrzynka narzędziowa pulpitu LXQt - Informacje techniczne&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="obsolete">Wersja</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="obsolete">Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation type="obsolete">Wersja debugowa</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation type="obsolete">Konfiguracja systemu</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation type="obsolete">Udostępniany katalog</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="obsolete">Tłumaczenia</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation type="obsolete">&lt;b&gt;Katalogi użytkownika&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation type="obsolete">Ścieżka dostępu plików Xdg</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation type="obsolete">Ścieżka dostępu konfiguracji Xdg</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation type="obsolete">Katalogi plików Xdg</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation type="obsolete">Ścieżka dostępu pamięci podręcznej Xdg</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="obsolete">Ścieżka dostępu środowiska uruchomieniowego Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation type="obsolete">Katalogi autostartu Xdg</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation type="obsolete">Ścieżka dostępu autostart Xdg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Rozwiązanie rezerwowe dla powiadomień</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Uśpij sesję</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz uśpić swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu nie jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernuj sesję</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz zahibernować swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz ponownie uruchomić swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz wyłączyć swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz się wylogować?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Uśpienie nie powiodło się.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Błąd wygaszacza ekranu</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Błąd podczas aktywacji wygaszacza ekranu</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Wystąpił błąd podczas wywołania wygaszacza ekranu. Nieznany błąd - nieudokumentowana wartość zwrócona przez xdg-screensaver: %1.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie uruchamia się (crash).</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie jest poprawnie zainstalowany.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie może zostać uruchomiony.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Błąd składni argumentów xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Akcja &quot;aktywacja&quot; zawiodła. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Wystąpił błąd podczas wywołania wygaszacza ekranu. Nieznany błąd - nieudokumentowany zwrot wartości z xdg-screensaver=%1.</translation>
    </message>
</context>
<context>
    <name>LXQt::ShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Wyczyść</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Brak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Błąd menedżera zasilania</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface jest nieprawidłowy</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Błąd menedżera zasilania (D-BUS call)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">O LXQt</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">O</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Autorzy</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Podziękowania</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Tłumaczenia</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Informacje techniczne</translation>
    </message>
</context>
</TS>
